#####################################
# Uncomment the 2 lines below if 
# 1) a new window doesn't open or 
# 2) matplotlib crashes
#####################################
import matplotlib
#matplotlib.use('Agg')
#####################################
import matplotlib.pyplot as plt

from classy import Class
import numpy as np

obh2grid=np.linspace(0.018, 0.026, 10)
rdsvals = np.zeros(len(obh2grid))

# based on Planck+BAO 2018
for i in range(len(obh2grid)):
    params = {
        'output': '',
        'h': 0.6770,
        'omega_b': obh2grid[i],
        'omega_cdm': 0.11923,
        'tau_reio': 0.0568}
    print("Now running class for model ",i)
    cosmo = Class()
    cosmo.set(params)
    cosmo.compute()
    rdsvals[i]=cosmo.get_current_derived_parameters(['rs_rec','ra_rec','rs_d'])['rs_d']

# This makes the plot and saves it as a PDF
print('Now making the plot...')
fig=plt.figure()
plt.plot(obh2grid, rdsvals, 'r', label='Planck 18')
plt.legend(loc='best')
plt.title(r'Sound horizon at dragging redshift vs $\Omega_b h^2$')
plt.xlabel(r'$\Omega_b h^2$')
plt.ylabel(r'$ rs_{d}(\Omega_b h^2)$')
plt.grid()
# On linux or if you have an X enviroment the following will open a window  
plt.show()

fig.savefig("./classy_other_rsd.pdf")

cosmo.empty()
cosmo.struct_cleanup()

print("Exiting...")
exit()